package javax.swing.text;

import java.text.CharacterIterator;

public class Segment implements Cloneable, CharacterIterator, CharSequence
{
    public char[] array;
    public int offset;
    public int count;
    private boolean partialReturn;
    private int pos;
    
    public Segment() {
        this(null, 0, 0);
    }
    
    public Segment(char[] array, int offset, int count) {
        this.array = array;
        this.offset = offset;
        this.count = count;
        this.partialReturn = false;
    }
    
    public void setPartialReturn(boolean partialReturn) {
        this.partialReturn = partialReturn;
    }
    
    public boolean isPartialReturn() {
        return this.partialReturn;
    }
    
    @Override
    public String toString() {
        if (this.array != null) {
            return new String(this.array, this.offset, this.count);
        }
        return "";
    }
    
    @Override
    public char first() {
        this.pos = this.offset;
        if (this.count != 0) {
            return this.array[this.pos];
        }
        return '\uffff';
    }
    
    @Override
    public char last() {
        this.pos = this.offset + this.count;
        if (this.count != 0) {
            --this.pos;
            return this.array[this.pos];
        }
        return '\uffff';
    }
    
    @Override
    public char current() {
        if (this.count != 0 && this.pos < this.offset + this.count) {
            return this.array[this.pos];
        }
        return '\uffff';
    }
    
    @Override
    public char next() {
        ++this.pos;
        int pos = this.offset + this.count;
        if (this.pos >= pos) {
            this.pos = pos;
            return '\uffff';
        }
        return this.current();
    }
    
    @Override
    public char previous() {
        if (this.pos == this.offset) {
            return '\uffff';
        }
        --this.pos;
        return this.current();
    }
    
    @Override
    public char setIndex(int n) {
        int n2 = this.offset + this.count;
        if (n < this.offset || n > n2) {
            throw new IllegalArgumentException("bad position: " + n);
        }
        this.pos = n;
        if (this.pos != n2 && this.count != 0) {
            return this.array[this.pos];
        }
        return '\uffff';
    }
    
    @Override
    public int getBeginIndex() {
        return this.offset;
    }
    
    @Override
    public int getEndIndex() {
        return this.offset + this.count;
    }
    
    @Override
    public int getIndex() {
        return this.pos;
    }
    
    @Override
    public char charAt(int index) {
        if (index < 0 || index >= this.count) {
            throw new StringIndexOutOfBoundsException(index);
        }
        return this.array[this.offset + index];
    }
    
    @Override
    public int length() {
        return this.count;
    }
    
    @Override
    public CharSequence subSequence(int index, int index2) {
        if (index < 0) {
            throw new StringIndexOutOfBoundsException(index);
        }
        if (index2 > this.count) {
            throw new StringIndexOutOfBoundsException(index2);
        }
        if (index > index2) {
            throw new StringIndexOutOfBoundsException(index2 - index);
        }
        Segment segment = new Segment();
        segment.array = this.array;
        segment.offset = this.offset + index;
        segment.count = index2 - index;
        return segment;
    }
    
    @Override
    public Object clone() {
        Object clone;
        try {
            clone = super.clone();
        }
        catch (CloneNotSupportedException ex) {
            clone = null;
        }
        return clone;
    }
}
